from __future__ import with_statement

from Foundation import *
from AppKit import *
import objc

# Local imports from within Circuit Editor
from CE.Component import Component
from draw_extras import *

import circuitsim

voltage_label_attribs = {
	NSFontAttributeName: load_font("Visea Tiny", 8),
	NSForegroundColorAttributeName: NSColor.whiteColor()
}

class VoltageSource(Component):
	width = 2
	height = 1
	pin_locations = [(-1,-0.5), (1,-0.5)]
	editable_properties = Component.editable_properties + \
		[("voltage", "Voltage", "float")]
	class_name = "Voltage Source"
		
	def __init__(self, serialized_form = None):
		if serialized_form:
			serialized_form, self.voltage = serialized_form
		else:
			self.voltage = 5.0
		self.component = circuitsim.VoltageSource(self.voltage)
		Component.__init__(self, serialized_form)

	def subdraw(self):

		with in_affine_transform(rescaler):
			NSImage.imageNamed_("Battery").drawAtPoint_fromRect_operation_fraction_(
				(-self.width/2.0*16.0,-self.height/2.0*16.0),
				NSZeroRect,
				NSCompositeSourceOver,
				1.0)
		
		draw_text_centered("%.1fV" % self.voltage, (0.40,0), voltage_label_attribs)
	
	def set_property(self, prop, value):
		if prop=="voltage":
			self.voltage = value
			self.component.voltage = value
		else:
			super(VoltageSource, self).set_property(prop, value)
	
	def serialize(self):
		return (super(VoltageSource,self).serialize(), self.voltage)