from Foundation import *
from AppKit import *
import objc

# Local imports from within Circuit Editor
from geometry import *

import circuitsim

# A Node object represents a continuous "chunk" of wires and pins. Pins and wires are said to be
# "connected" to the node if the node represents the chunk that they are a part of. All the pins and
# wires in a node have the same voltage, and the sum of all the currents in and out of the node
# equals zero. Node objects are dynamically created and deleted as wires and components are moved
# around in the GUI.
class Node(object):
	next_id = 0
	
	def __init__(self, circuit):
		# The Circuit that this node is a part of
		self.circuit = circuit
		self.circuit.nodes.add(self)
		
		# A set of all the wires and pins that are connected to this node
		self.users = set()
		
		# The internal circuitsim Node object that this Node object represents
		self.node = circuitsim.Node(self.circuit.circuit)
		
		# ID is used for debugging
		self.id = Node.next_id
		Node.next_id += 1
	
	def destroy(self):
		# Destroys the node when it is no longer in use
		assert not self.users
		self.node.delete()
		self.circuit.nodes.remove(self)
	
	def voltage(self):
		# Returns the current voltage on the node.
		return self.node.voltage()