from __future__ import with_statement

from Foundation import *
from AppKit import *
import objc

# Local imports from within Circuit Editor
from CE.Component import Component
from draw_extras import *

import circuitsim

capacitance_label_attribs = {
	NSFontAttributeName: load_font("Visea Tiny", 8),
	NSForegroundColorAttributeName: NSColor.whiteColor()
}

class Capacitor(Component):
	width = 1
	height = 2
	pin_locations = [(-0.5,-1), (0.5,-1)]
	editable_properties = Component.editable_properties + \
		[("capacitance", "Capacitance (F)", "smallfloat")]
	class_name = "Capacitor"
		
	def __init__(self, serialized_form = None):
		if serialized_form:
			serialized_form, self.capacitance = serialized_form
		else:
			self.capacitance = 0.0001
		self.component = circuitsim.Capacitor(self.capacitance)
		Component.__init__(self, serialized_form)

	def subdraw(self):
		
		with in_affine_transform(rescaler):
			NSImage.imageNamed_("Capacitor").drawAtPoint_fromRect_operation_fraction_(
				(-self.width/2.0*16.0,-self.height/2.0*16.0),
				NSZeroRect,
				NSCompositeSourceOver,
				1.0)
		
		if self.capacitance>=0.1: cap = "%.1fF"%self.capacitance
		elif self.capacitance>=0.000001: cap = "%duF"%(self.capacitance*1000000)
		elif self.capacitance>=0.000000001: cap = "%dnF"%(self.capacitance*1000000000)
		elif self.capacitance>=0.000000000001: cap = "%dpF"%(self.capacitance*1000000000000)
		else: cap = "tiny"
		
		rotator = NSAffineTransform.transform()
		rotator.rotateByDegrees_(90)
		with in_affine_transform(rotator):
			draw_text_centered(cap, (0,0), capacitance_label_attribs)
	
	def set_property(self, prop, value):
		if prop=="capacitance":
			self.capacitance = value
			self.component.capacitance = value
		else:
			super(Capacitor, self).set_property(prop, value)
	
	def serialize(self):
		return (super(Capacitor,self).serialize(), self.capacitance)