from __future__ import with_statement

from Foundation import *
from AppKit import *
import objc

# Local imports from within Circuit Editor
from CE.Component import Component
from geometry import transform_point, transform_rect, make_affine_transform, disect_affine_transform
from draw_extras import *

import circuitsim

display_attribs = {
	NSFontAttributeName: NSFont.fontWithName_size_("Monaco", 11),
	NSForegroundColorAttributeName: NSColor.redColor()
}

class CurrentMeter(Component):
	width = 5
	height = 1
	pin_locations = [(-2.5,-0.5), (2.5,-0.5)]
	dynamic_appearance = True
	class_name = "Current Meter"
		
	def __init__(self, serialized_form=None):
		self.component = circuitsim.CurrentMeter()
		Component.__init__(self, serialized_form)

	def subdraw(self):
		
		with in_affine_transform(rescaler):
			NSImage.imageNamed_("CurrentMeter").drawAtPoint_fromRect_operation_fraction_(
				(-self.width/2.0*16.0,-self.height/2.0*16.0),
				NSZeroRect,
				NSCompositeSourceOver,
				1.0)
				
		if self.circuit and self.circuit.calculation_valid:
			
			# Draw current on screen.
			
			current = self.component.meter_current()
			if current>0: text = "+%.2fA" % current
			elif current<0: text = "-%.2fA" % abs(current)
			else: text = "0.00A"
			
			# The current on the screen must be drawn with a separate transform, or else it may be 
			# mirrored and/or upside-down.
			trans = NSAffineTransform.new()
			if self.flip: trans.scaleXBy_yBy_(1, -1)
			if self.rotation>=180: trans.rotateByDegrees_(180)
			
			with in_affine_transform(trans):
				draw_text_centered(text, (0,0), display_attribs)
					
		
		