from __future__ import with_statement

from Foundation import *
from AppKit import *
import objc

# Local imports from within Circuit Editor
from CE.Component import Component
from draw_extras import *

import circuitsim

class LightBulb(Component):
	width = 2
	height = 2
	pin_locations = [(-1,-1), (1,-1)]
	editable_properties = Component.editable_properties + \
		[("resistance", "Resistance", "float")]
	class_name = "Light Bulb"
	dynamic_appearance = True
		
	def __init__(self, serialized_form = None):
		if serialized_form:
			serialized_form, self.resistance = serialized_form
		else:
			self.resistance = 5.0
		self.component = circuitsim.Resistor(self.resistance)
		Component.__init__(self, serialized_form)

	def subdraw(self):
		with in_affine_transform(rescaler):
			NSImage.imageNamed_("LightBulb").drawAtPoint_fromRect_operation_fraction_(
				(-self.width/2.0*16.0, -self.height/2.0*16.0),
				NSZeroRect,
				NSCompositeSourceOver,
				1.0)
			if self.circuit and self.circuit.calculation_valid:
				glow_level = min(abs(self.component.current(0)), 1.0)
				NSImage.imageNamed_("LightBulbGlow").drawAtPoint_fromRect_operation_fraction_(
					(-self.width/2.0*16.0, -self.height/2.0*16.0),
					NSZeroRect,
					NSCompositeSourceOver,
					glow_level)
	
	def set_property(self, prop, value):
		if prop=="resistance":
			self.resistance = value
			self.component.resistance = value
		else:
			super(LightBulb, self).set_property(prop, value)
	
	def serialize(self):
		return (super(LightBulb,self).serialize(), self.resistance)