from __future__ import with_statement

from Foundation import *
from AppKit import *
import objc

# Local imports from within Circuit Editor
from CE.Component import Component
from draw_extras import *

import circuitsim

class Resistor(Component):
	width = 2
	height = 1
	pin_locations = [(-1,-0.5), (1,-0.5)]
	editable_properties = Component.editable_properties + \
		[("resistance", "Resistance", "float")]
	class_name = "Resistor"
		
	def __init__(self, serialized_form = None):
		if serialized_form:
			serialized_form, self.resistance = serialized_form
		else:
			self.resistance = 5.0
		self.component = circuitsim.Resistor(self.resistance)
		Component.__init__(self, serialized_form)

	def subdraw(self):
		with in_affine_transform(rescaler):
			NSImage.imageNamed_("Resistor").drawAtPoint_fromRect_operation_fraction_(
				(-self.width/2.0*16.0,-self.height/2.0*16.0),
				NSZeroRect,
				NSCompositeSourceOver,
				1.0)
	
	def set_property(self, prop, value):
		if prop=="resistance":
			self.resistance = value
			self.component.resistance = value
		else:
			super(Resistor, self).set_property(prop, value)
	
	def serialize(self):
		return (super(Resistor,self).serialize(), self.resistance)