from __future__ import with_statement

from Foundation import *
from AppKit import *
import objc

# Local imports from within Circuit Editor
from CE.Component import Component
from notifications import post_notification
from draw_extras import *

import circuitsim

class VariableVoltageSource(Component):
	width = 5
	height = 1
	pin_locations = [(-2.5,-0.5), (2.5,-0.5)]
	editable_properties = Component.editable_properties + \
		[("maxvoltage", "Max Voltage", "float")]
	class_name = "Variable Voltage Source"
	
	manipulation_zones = [((-2.1,-0.4), (4.2,0.4))]
		
	def __init__(self, serialized_form = None):
		if serialized_form:
			serialized_form, self.maxvoltage, self.setting = serialized_form
		else:
			self.maxvoltage = 5.0
			self.setting = 0.5
		self.component = circuitsim.VoltageSource(self.maxvoltage*self.setting)
		Component.__init__(self, serialized_form)

	def subdraw(self):
	
		with in_affine_transform(rescaler):
			NSImage.imageNamed_("VariableVoltageSource").drawAtPoint_fromRect_operation_fraction_(
				(-self.width/2.0*16.0,-self.height/2.0*16.0),
				NSZeroRect,
				NSCompositeSourceOver,
				1.0)
		
		NSColor.whiteColor().set()
		c = (-2.1+4.2*self.setting, -0.2)
		NSRectFill(((c[0]-0.2,c[1]-0.2), (0.4, 0.5)))
	
	def start_manipulation(self, p):
		self.continue_manipulation(p)
	
	def continue_manipulation(self, p):
		setting = (p[0] - (-2.1)) / 4.2
		if setting<0: setting=0
		if setting>1: setting=1
		self.setting = setting
		self.component.voltage = self.setting * self.maxvoltage
		post_notification("CircuitElementManipulated", self.circuit, self)
	
	def set_property(self, prop, value):
		if prop=="maxvoltage":
			self.maxvoltage = value
			self.component.voltage = self.maxvoltage * self.setting
		else:
			super(VariableVoltageSource, self).set_property(prop, value)
	
	def serialize(self):
		return (super(VariableVoltageSource,self).serialize(), self.maxvoltage, self.setting)